# poodle_async_mini
Auto-generated OpenAPI spec for Moodle's Webservice API.

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 5.0.2 (Build: 20250811)
- Package version: 5.0.2.post2
- Generator version: 7.15.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.9+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/bchmnn/poodle.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/bchmnn/poodle.git`)

Then import the package:
```python
import poodle_async_mini
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import poodle_async_mini
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import poodle_async_mini
from poodle_async_mini.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://localhost
# See configuration.py for a list of all supported configuration parameters.
configuration = poodle_async_mini.Configuration(
    host = "https://localhost"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: wstoken
configuration.api_key['wstoken'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['wstoken'] = 'Bearer'


# Enter a context with an instance of the API client
async with poodle_async_mini.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = poodle_async_mini.DefaultApi(api_client)
    courseid = 56 # int | course id
    options = [poodle_async_mini.CoreCourseGetContentsParametersOptionsInner()] # List[CoreCourseGetContentsParametersOptionsInner] | Options, used since Moodle 2.9 (optional)

    try:
        # Get course contents
        api_response = await api_instance.core_course_get_contents(courseid, options=options)
        print("The response of DefaultApi->core_course_get_contents:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling DefaultApi->core_course_get_contents: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://localhost*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*DefaultApi* | [**core_course_get_contents**](docs/DefaultApi.md#core_course_get_contents) | **POST** /webservice/rest/server.php#core_course_get_contents | Get course contents
*DefaultApi* | [**core_enrol_get_users_courses**](docs/DefaultApi.md#core_enrol_get_users_courses) | **POST** /webservice/rest/server.php#core_enrol_get_users_courses | Get the list of courses where a user is enrolled in
*DefaultApi* | [**core_group_get_course_groups**](docs/DefaultApi.md#core_group_get_course_groups) | **POST** /webservice/rest/server.php#core_group_get_course_groups | Returns all groups in specified course.
*DefaultApi* | [**core_webservice_get_site_info**](docs/DefaultApi.md#core_webservice_get_site_info) | **POST** /webservice/rest/server.php#core_webservice_get_site_info | Return some site info / user info / list web service functions
*DefaultApi* | [**gradereport_user_get_grade_items**](docs/DefaultApi.md#gradereport_user_get_grade_items) | **POST** /webservice/rest/server.php#gradereport_user_get_grade_items | Returns the complete list of grade items for users in a course
*DefaultApi* | [**login_token**](docs/DefaultApi.md#login_token) | **POST** /login/token.php | 
*DefaultApi* | [**mod_assign_get_assignments**](docs/DefaultApi.md#mod_assign_get_assignments) | **POST** /webservice/rest/server.php#mod_assign_get_assignments | Returns the courses and assignments for the users capability
*DefaultApi* | [**mod_assign_get_submissions**](docs/DefaultApi.md#mod_assign_get_submissions) | **POST** /webservice/rest/server.php#mod_assign_get_submissions | Returns the submissions for assignments
*DefaultApi* | [**mod_assign_list_participants**](docs/DefaultApi.md#mod_assign_list_participants) | **POST** /webservice/rest/server.php#mod_assign_list_participants | List the participants for a single assignment, with some summary info about their submissions.
*DefaultApi* | [**tool_mobile_get_public_config**](docs/DefaultApi.md#tool_mobile_get_public_config) | **GET** /lib/ajax/service-nologin.php#tool_mobile_get_public_config | Returns a list of the site public settings, those not requiring authentication.


## Documentation For Models

 - [CoreCourseGetContentsParametersOptionsInner](docs/CoreCourseGetContentsParametersOptionsInner.md)
 - [CoreCourseGetContentsResponseInner](docs/CoreCourseGetContentsResponseInner.md)
 - [CoreCourseGetContentsResponseInnerModulesInner](docs/CoreCourseGetContentsResponseInnerModulesInner.md)
 - [CoreCourseGetContentsResponseInnerModulesInnerActivitybadge](docs/CoreCourseGetContentsResponseInnerModulesInnerActivitybadge.md)
 - [CoreCourseGetContentsResponseInnerModulesInnerActivitybadgeOneOf](docs/CoreCourseGetContentsResponseInnerModulesInnerActivitybadgeOneOf.md)
 - [CoreCourseGetContentsResponseInnerModulesInnerActivitybadgeOneOfBadgeextraattributesInner](docs/CoreCourseGetContentsResponseInnerModulesInnerActivitybadgeOneOfBadgeextraattributesInner.md)
 - [CoreCourseGetContentsResponseInnerModulesInnerCompletiondata](docs/CoreCourseGetContentsResponseInnerModulesInnerCompletiondata.md)
 - [CoreCourseGetContentsResponseInnerModulesInnerCompletiondataDetailsInner](docs/CoreCourseGetContentsResponseInnerModulesInnerCompletiondataDetailsInner.md)
 - [CoreCourseGetContentsResponseInnerModulesInnerCompletiondataDetailsInnerRulevalue](docs/CoreCourseGetContentsResponseInnerModulesInnerCompletiondataDetailsInnerRulevalue.md)
 - [CoreCourseGetContentsResponseInnerModulesInnerContentsInner](docs/CoreCourseGetContentsResponseInnerModulesInnerContentsInner.md)
 - [CoreCourseGetContentsResponseInnerModulesInnerContentsInnerTagsInner](docs/CoreCourseGetContentsResponseInnerModulesInnerContentsInnerTagsInner.md)
 - [CoreCourseGetContentsResponseInnerModulesInnerContentsinfo](docs/CoreCourseGetContentsResponseInnerModulesInnerContentsinfo.md)
 - [CoreCourseGetContentsResponseInnerModulesInnerDatesInner](docs/CoreCourseGetContentsResponseInnerModulesInnerDatesInner.md)
 - [CoreEnrolGetUsersCoursesResponseInner](docs/CoreEnrolGetUsersCoursesResponseInner.md)
 - [CoreEnrolGetUsersCoursesResponseInnerOverviewfilesInner](docs/CoreEnrolGetUsersCoursesResponseInnerOverviewfilesInner.md)
 - [CoreGroupGetCourseGroupsResponseInner](docs/CoreGroupGetCourseGroupsResponseInner.md)
 - [CoreWebserviceGetSiteInfoResponse](docs/CoreWebserviceGetSiteInfoResponse.md)
 - [CoreWebserviceGetSiteInfoResponseAdvancedfeaturesInner](docs/CoreWebserviceGetSiteInfoResponseAdvancedfeaturesInner.md)
 - [CoreWebserviceGetSiteInfoResponseFunctionsInner](docs/CoreWebserviceGetSiteInfoResponseFunctionsInner.md)
 - [GradereportUserGetGradeItemsResponse](docs/GradereportUserGetGradeItemsResponse.md)
 - [GradereportUserGetGradeItemsResponseUsergradesInner](docs/GradereportUserGetGradeItemsResponseUsergradesInner.md)
 - [GradereportUserGetGradeItemsResponseUsergradesInnerGradeitemsInner](docs/GradereportUserGetGradeItemsResponseUsergradesInnerGradeitemsInner.md)
 - [GradereportUserGetGradeItemsResponseWarningsInner](docs/GradereportUserGetGradeItemsResponseWarningsInner.md)
 - [LoginToken200Response](docs/LoginToken200Response.md)
 - [ModAssignGetAssignmentsResponse](docs/ModAssignGetAssignmentsResponse.md)
 - [ModAssignGetAssignmentsResponseCoursesInner](docs/ModAssignGetAssignmentsResponseCoursesInner.md)
 - [ModAssignGetAssignmentsResponseCoursesInnerAssignmentsInner](docs/ModAssignGetAssignmentsResponseCoursesInnerAssignmentsInner.md)
 - [ModAssignGetAssignmentsResponseCoursesInnerAssignmentsInnerConfigsInner](docs/ModAssignGetAssignmentsResponseCoursesInnerAssignmentsInnerConfigsInner.md)
 - [ModAssignGetAssignmentsResponseWarningsInner](docs/ModAssignGetAssignmentsResponseWarningsInner.md)
 - [ModAssignGetSubmissionsResponse](docs/ModAssignGetSubmissionsResponse.md)
 - [ModAssignGetSubmissionsResponseAssignmentsInner](docs/ModAssignGetSubmissionsResponseAssignmentsInner.md)
 - [ModAssignGetSubmissionsResponseAssignmentsInnerSubmissionsInner](docs/ModAssignGetSubmissionsResponseAssignmentsInnerSubmissionsInner.md)
 - [ModAssignGetSubmissionsResponseAssignmentsInnerSubmissionsInnerPluginsInner](docs/ModAssignGetSubmissionsResponseAssignmentsInnerSubmissionsInnerPluginsInner.md)
 - [ModAssignGetSubmissionsResponseAssignmentsInnerSubmissionsInnerPluginsInnerEditorfieldsInner](docs/ModAssignGetSubmissionsResponseAssignmentsInnerSubmissionsInnerPluginsInnerEditorfieldsInner.md)
 - [ModAssignGetSubmissionsResponseAssignmentsInnerSubmissionsInnerPluginsInnerFileareasInner](docs/ModAssignGetSubmissionsResponseAssignmentsInnerSubmissionsInnerPluginsInnerFileareasInner.md)
 - [ModAssignListParticipantsResponseInner](docs/ModAssignListParticipantsResponseInner.md)
 - [ModAssignListParticipantsResponseInnerCustomfieldsInner](docs/ModAssignListParticipantsResponseInnerCustomfieldsInner.md)
 - [ModAssignListParticipantsResponseInnerEnrolledcoursesInner](docs/ModAssignListParticipantsResponseInnerEnrolledcoursesInner.md)
 - [ModAssignListParticipantsResponseInnerGroupsInner](docs/ModAssignListParticipantsResponseInnerGroupsInner.md)
 - [ModAssignListParticipantsResponseInnerPreferencesInner](docs/ModAssignListParticipantsResponseInnerPreferencesInner.md)
 - [ModAssignListParticipantsResponseInnerRolesInner](docs/ModAssignListParticipantsResponseInnerRolesInner.md)
 - [ToolMobileGetPublicConfigResponse](docs/ToolMobileGetPublicConfigResponse.md)
 - [ToolMobileGetPublicConfigResponseIdentityprovidersInner](docs/ToolMobileGetPublicConfigResponseIdentityprovidersInner.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="wstoken"></a>
### wstoken

- **Type**: API key
- **API key parameter name**: wstoken
- **Location**: URL query string


## Author




